@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import re
-from typing import Generator
+from typing import Iterable
 
 from hatch.publish.plugin.interface import PublisherInterface
 from hatch.utils.fs import Path
@@ -53,17 +53,11 @@ class IndexPublisher(PublisherInterface):
 
             artifacts = [DEFAULT_BUILD_DIRECTORY]
 
-        if 'repo' in options:
-            repo = options['repo']
-        else:
-            repo = self.plugin_config.get('repo', 'main')
+        repo = options['repo'] if 'repo' in options else self.plugin_config.get('repo', 'main')
 
         repos = self.get_repos()
 
-        if repo in repos:
-            repo_config = repos[repo]
-        else:
-            repo_config = {'url': repo}
+        repo_config = repos[repo] if repo in repos else {'url': repo}
 
         index = PackageIndex(
             repo_config['url'],
@@ -148,17 +142,18 @@ class IndexPublisher(PublisherInterface):
                 index.upload_artifact(artifact, data)
             except Exception as e:
                 self.app.display_error('failed')
-                self.app.abort(str(e).replace(index.auth, '*****'))
+                self.app.abort(f'Error uploading to repository: {index.repo} - {e}'.replace(index.auth, '*****'))
             else:
                 self.app.display_success('success')
 
                 existing_artifacts[project_name].add(artifact.name)
                 project_versions[project_name][data['version']] = None
 
-        if not artifacts_found:
-            self.app.abort('No artifacts found')
-        elif not project_versions:
-            self.app.abort(code=0)
+        if not options['initialize_auth']:
+            if not artifacts_found:
+                self.app.abort('No artifacts found')
+            elif not project_versions:
+                self.app.abort(code=0)
 
         for project_name, versions in project_versions.items():
             self.app.display_info()
@@ -175,7 +170,7 @@ class IndexPublisher(PublisherInterface):
             keyring.set_password(repo, user, auth)
 
 
-def recurse_artifacts(artifacts: list, root) -> Generator[Path, None, None]:
+def recurse_artifacts(artifacts: list, root) -> Iterable[Path]:
     for artifact in artifacts:
         artifact = Path(artifact)
         if not artifact.is_absolute():
